/*

Copyright _ 2005, Apple Computer, Inc.  All rights reserved.
NOTE:  Use of this source code is subject to the terms of the Software
License Agreement for Mac OS X, which accompanies the code.  Your use
of this source code signifies your agreement to such license terms and
conditions.  Except as expressly granted in the Software License Agreement
for Mac OS X, no other copyright, patent, or other intellectual property
license or right is granted, either expressly or by implication, by Apple.

*/

/**************************/
// General live-resize code
// This code shows how to implement live-resizing in a widget
/**************************/

var lastPos;		// tracks where the last mouse position was throughout the drag

// The mouseDown function is called the user clicks on the growbox.  It prepares the
// widget to be resized and registers handlers for the resizing operations
function mouseDown(event)
{

	var x = event.x + window.screenX;		// the placement of the click
	var y = event.y + window.screenY;
	
	document.addEventListener("mousemove", mouseMove, true);  	// begin tracking the move
	document.addEventListener("mouseup", mouseUp, true);		// and notify when the drag ends

	lastPos = {x:x, y:y};		// track where the initial mouse down was, for later comparisons
								// the mouseMove function

	event.stopPropagation();
	event.preventDefault();
}


// mouseMove performs the actual resizing of the widget.  It is called after mouseDown
// activates it and every time the mouse moves.
function mouseMove(event)
{
	
	var screenX = event.x + window.screenX;		// retrieves the current mouse position
	var screenY = event.y + window.screenY;
		
	var deltaX = 0;		// will hold the change since the last mouseMove event
	var deltaY = 0;

	if ( (window.outerWidth + (screenX - lastPos.x)) >= 250 ) { 		// sets a minimum width constraint
		deltaX = screenX - lastPos.x;								// if we're greater than the constraint,
		lastPos.x = screenX;										// save the change and update our past position
	}

	if ( (window.outerHeight + (screenY - lastPos.y)) >= 150 ) {		// setting contrains for the heght
		deltaY = screenY - lastPos.y;
		lastPos.y = screenY;
	}
	
	window.resizeBy(deltaX, deltaY);
	setTimeout('update_scroller()', 0);
	widget.setPreferenceForKey(window.outerWidth, widget.identifier+'width');
	widget.setPreferenceForKey(window.outerHeight, widget.identifier+'height');

	event.stopPropagation();
	event.preventDefault();
}


// mouseUp is called when the user stops resizing the widget.  It removes the mouseMove and
// mouseUp event handlers, so that the widget doesn't continute resizing (because the mouse
// button is now up
function mouseUp(event)
{
	document.removeEventListener("mousemove", mouseMove, true);
	document.removeEventListener("mouseup", mouseUp, true);	

	event.stopPropagation();
	event.preventDefault();
}
